"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.filter = exports.updateSessionId = exports.controlGetCarList = exports.initControlSocketServer = exports.broadcastMsg = void 0;
const serverConfig_1 = require("../config/serverConfig");
const cronJob_1 = require("../data/cronJob");
const socket_server_1 = require("../net/socket_server");
const log_1 = require("../util/log");
let qs = require('qs');
// 展示端连接池
let viewPool = {};
// ws对象
let controlWs;
/**
 * 广播消息
 * @param data 需要广播的数据体 类型:object
 */
function broadcastMsg(data) {
    for (let userId in viewPool) {
        viewPool[userId].send(JSON.stringify(data));
    }
}
exports.broadcastMsg = broadcastMsg;
/**
 * 解析请求url 获取到ip
 * @param req ws中参数req
 * @returns ip
 */
function analysisUserUrl(req) {
    let ip = req.headers['x-forwarded-for'] || req.connection.remoteAddress || req.socket.remoteAddress || req.connection.socket.remoteAddress;
    return ip;
}
/**
 * 初始化用于操控的Socket服务
 * @param port 端口号
 */
async function initControlSocketServer(port) {
    socket_server_1.Socket.createServer(port, function (wss) {
        wss.on('connection', function (ws, req) {
            let ip = analysisUserUrl(req);
            if (req.url.indexOf('connect') == -1) {
                log_1.logError("连接错误,连接并没有connect参数", req.url);
                return;
            }
            let paramater = qs.parse(req.url.split('?')[1]);
            if (!paramater.role || (paramater.role != "view" && paramater.role != "control")) {
                console.log("连接参数错误");
                log_1.logError("连接错误,连接并没有role参数", req.url);
                return;
            }
            else if (paramater.role == "view" && !paramater.pageName) {
                console.log("展示端无页面参数");
                return;
            }
            let userId = `${paramater.role}${ip}`;
            ws.userId = userId;
            ws.userType = paramater.role;
            if (paramater.role == "view") {
                viewPool[userId] = ws;
                // console.log(`连接成功至:${paramater.pageName}页面`);
            }
            else {
                if (controlWs)
                    console.log("重复连接");
                controlWs = ws;
                // console.log(`控制端已连接:${userId}`);
            }
            //==============连接成功
            ws.on('message', function (msg) {
                let { type, pageName, data } = JSON.parse(msg);
                if (type == 'heart') { //回应心跳包
                    ws.send(JSON.stringify({ success: true, code: 199 }));
                    return;
                }
                //不接收控制端之外的消息
                if (ws.userType != "control") {
                    return;
                }
                //过滤器
                filter(data);
                //下发消息给展示端
                broadcastMsg(data);
            });
            ws.on('close', function (data) {
                if (ws._socket && ws._socket._peername && ws._socket._peername.address) {
                    let userId = ws.userId;
                    if (ws.userType == "control") {
                        controlWs = null;
                    }
                    else {
                        delete viewPool[userId];
                    }
                    // console.log("close", userId);
                }
            });
        });
    });
}
exports.initControlSocketServer = initControlSocketServer;
//控制端获取小车列表
async function controlGetCarList(req, res) {
    let { enterpriseVehicleList } = await cronJob_1.getInterfaceByInterfaceName(serverConfig_1.dataCenterInterfaceConfig.enterpriseVehicleList, {});
    //todo 最后加鉴权
    // let carList = controlGetOnlieCarList();//todo 改这里
    let carList = [];
    enterpriseVehicleList.forEach(info => {
        let vehicleList = info.vehicleList;
        vehicleList.forEach(list => {
            let { vin, enterprise, online } = list;
            let isOnline = "";
            switch (online) {
                case 0:
                    isOnline = "离线";
                    break;
                case 1:
                    isOnline = "在线";
                    break;
            }
            carList.push({ vin, enterprise, isOnline });
        });
    });
    // res.send({carList});
    res.send({ carList });
}
exports.controlGetCarList = controlGetCarList;
//小车详情 点击播放视频
let carVideoQueue = { vin: "", sessionId: "", index: "", isOpen: false }; //{sessionId:"", isOpen }
function updateSessionId(vin, sessionId) {
    if (!vin && vin != carVideoQueue.vin) {
        console.log("逻辑错误 ");
    }
    carVideoQueue.sessionId = sessionId;
}
exports.updateSessionId = updateSessionId;
let carHeart;
async function filter(msg) {
    if (msg.pageName == "数据服务平台") {
        switch (msg.type) {
            case "打开监控":
                carVideoQueue.isOpen = true;
                carVideoQueue.index = msg.index;
                carHeart = setInterval(() => {
                    videoBeat();
                }, 120 * 1000);
                break;
            case "暂停监控":
                carVideoQueue.isOpen = false;
                clearInterval(carHeart);
                break;
            case "继续监控":
                if (!carVideoQueue.isOpen)
                    break;
                carVideoQueue.isOpen = true;
                carHeart = setInterval(() => {
                    videoBeat();
                }, 120 * 1000);
                break;
            case "小车详情弹框":
                let carId = msg.id;
                carVideoQueue.vin = carId;
                carVideoQueue.sessionId = "";
                carVideoQueue.index = "";
                carVideoQueue.isOpen = false;
                clearInterval(carHeart);
                break;
        }
        console.log(msg);
    }
}
exports.filter = filter;
async function videoBeat() {
    //心跳
    if (!carVideoQueue.vin)
        clearInterval(carHeart);
    await cronJob_1.getInterfaceByInterfaceName(serverConfig_1.dataCenterInterfaceConfig.videoBeat, { vin: carVideoQueue.vin });
}
//# sourceMappingURL=control.js.map