"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.initBasicData = void 0;
const enum_1 = require("../config/enum");
const enterprise_1 = require("../data/enterprise/enterprise");
const fuhuaqi_1 = require("../data/fuHuaQi/fuhuaqi");
const tools_1 = require("./tools");
const fs = require('fs');
const xlsx = require('node-xlsx');
const path = require('path');
const OldTypeChangeConfig = {
    "文化创意": enum_1.FUHUAINDUSTRY.文化创意,
    "TMT": enum_1.FUHUAINDUSTRY.文化创意,
    "集成电路": enum_1.FUHUAINDUSTRY.集成电路,
    "微电子": enum_1.FUHUAINDUSTRY.集成电路,
    "先进制造": enum_1.FUHUAINDUSTRY.集成电路,
    "自动化": enum_1.FUHUAINDUSTRY.集成电路,
    "芯片半导体": enum_1.FUHUAINDUSTRY.集成电路,
    "电子商务": enum_1.FUHUAINDUSTRY.综合型,
    "物联网": enum_1.FUHUAINDUSTRY.综合型,
    "农业": enum_1.FUHUAINDUSTRY.综合型,
    "综合型": enum_1.FUHUAINDUSTRY.综合型,
    "区块链": enum_1.FUHUAINDUSTRY.信息技术,
    "电子信息": enum_1.FUHUAINDUSTRY.信息技术,
    "信息安全": enum_1.FUHUAINDUSTRY.信息技术,
    "新一代信息技术": enum_1.FUHUAINDUSTRY.信息技术,
    "互联网": enum_1.FUHUAINDUSTRY.信息技术,
    "高技术服务": enum_1.FUHUAINDUSTRY.信息技术,
    "大数据信息技术": enum_1.FUHUAINDUSTRY.信息技术,
    "技术研发": enum_1.FUHUAINDUSTRY.信息技术,
    "信息科技": enum_1.FUHUAINDUSTRY.信息技术,
    "软件": enum_1.FUHUAINDUSTRY.信息技术,
    "信息服务业": enum_1.FUHUAINDUSTRY.信息技术,
    "元宇宙": enum_1.FUHUAINDUSTRY.信息技术,
    "网络科技领域": enum_1.FUHUAINDUSTRY.信息技术,
    "IT计算机": enum_1.FUHUAINDUSTRY.信息技术,
    "工业4.0": enum_1.FUHUAINDUSTRY.人工智能,
    "人工智能大数据": enum_1.FUHUAINDUSTRY.人工智能,
    "智能制造": enum_1.FUHUAINDUSTRY.人工智能,
    "人工智能": enum_1.FUHUAINDUSTRY.人工智能,
    "生物医药": enum_1.FUHUAINDUSTRY.生物医药,
    "医疗器械": enum_1.FUHUAINDUSTRY.生物医药,
    "生物科技": enum_1.FUHUAINDUSTRY.生物医药,
    "大健康": enum_1.FUHUAINDUSTRY.生物医药
};
/**
 * 获取当个excel文件数据
 * @param filePath
 * @returns
 */
function getExcel(filePath) {
    const workSheetsFromFile = xlsx.parse(filePath);
    let sheetMap = {};
    let sheetList = [];
    for (let i = 0; i < workSheetsFromFile.length; i++) {
        let sheetInfo = workSheetsFromFile[i];
        sheetMap[sheetInfo.name] = sheetInfo.data;
        sheetList.push(sheetInfo);
    }
    return { sheetMap, sheetList };
}
/**
 * 初始化原始数据
 */
async function initBasicData() {
    await initFuHuaQiData();
    await initEnterprise();
}
exports.initBasicData = initBasicData;
async function initFuHuaQiData() {
    let count = await fuhuaqi_1.findFuHuaQiUserCount({});
    if (count > 10) {
        console.log("*** 孵化器数据 无需初始化");
        return;
    }
    let { sheetMap } = getExcel(path.join(__dirname.substring(0, __dirname.indexOf("out")), "res", '孵化器原始数据.xlsx'));
    let dataList = sheetMap['孵化器'];
    let titleMap = {
        "0": "operationName",
        "1": "name",
        "2": "uscc",
        "3": "lv",
        "4": "industry",
        "5": "institutionalNature",
        "6": "liaison",
        "7": "liaisonPhone",
        "8": "personInCharge",
        "9": "personInChargePhone",
        "11": "acreageTotal",
        "12": "incubatedAcreage",
        "13": "acreagePersonalUse", //孵化器自用面积
    };
    let addList = [];
    dataList.forEach((subList, index) => {
        if (!index)
            return; //跳过表头
        let addDataInfo = {
            firstLoginIsChangePwd: false,
            userState: false,
            virtualEnterpriseNum: 0
        };
        for (let i = 0; i < 12; i++) {
            if (i == 10)
                continue;
            let item = subList[i];
            let key = titleMap[i];
            let value = item;
            if (i == 2) {
                let itemStr = `${item}`;
                addDataInfo.pwd = tools_1.getPwdMd5(itemStr, itemStr.slice(itemStr.length - 6));
            }
            if (i == 3) {
                value = enum_1.FUHUAQILV[item] || 0;
            }
            if (i == 4) {
                value = [];
                if (item) {
                    let oldList = item.split(',');
                    oldList.forEach(oldStr => {
                        value.push(OldTypeChangeConfig[oldStr.trim()]);
                    });
                }
            }
            if (i == 5) {
                value = enum_1.INSTITUTIONALNATURE[item] || 0;
            }
            addDataInfo[key] = value;
        }
        addList.push(addDataInfo);
    });
    await fuhuaqi_1.createFuHuaQiToList(addList);
    console.log("---> 孵化器数据 初始化成功");
}
async function initEnterprise() {
    let count = await enterprise_1.findEnterpriseCount({});
    if (count > 10) {
        console.log("*** 企业数据 无需初始化");
        return;
    }
    let { sheetMap } = getExcel(path.join(__dirname.substring(0, __dirname.indexOf("out")), "res", '企业原始数据.xlsx'));
    let dataList = sheetMap['在孵企业'];
    let fuHuaQiUsccMap = await fuhuaqi_1.findAllFuHuaQiOperationUsccMap();
    let titleMap = {
        "0": "name",
        "3": "fuHuaQiUscc",
        "4": "uscc",
        "5": "industry",
        "8": "logonTime",
        "9": "timeOfImmigration",
        "10": "oldLogonAdd",
        "13": "logonAdd",
        "14": "operatingAdd",
        "15": "firstIncubationTime",
        "16": "isNaturalPersonHolding",
        "18": "leasedArea", //租赁面积（平方米）
    };
    let titleIndexList = Object.keys(titleMap);
    let addList = [];
    dataList.forEach((subList, index) => {
        if (!index)
            return; //跳过表头
        let addDataInfo = {
            draftLock: true,
            createTime: new Date().valueOf(),
            isCreate: true
        };
        let isJump = false;
        for (let subI = 0; subI < titleIndexList.length; subI++) {
            let i = parseInt(titleIndexList[subI]);
            let item = subList[i];
            let key = titleMap[i];
            let value = item;
            if (i == 3) {
                if (!item || !fuHuaQiUsccMap[item]) {
                    isJump = true;
                    break;
                }
                value = fuHuaQiUsccMap[item];
                addDataInfo.taskId = tools_1.getTaskId(value);
            }
            if (i == 4) {
                if (!item) {
                    isJump = true;
                    break;
                }
            }
            if (i == 5) {
                value = [];
                if (item) {
                    let oldList = item.split(',');
                    oldList.forEach(oldStr => {
                        let valueNum = enum_1.INDUSTRY[oldStr.trim()];
                        if (valueNum)
                            value.push(valueNum);
                    });
                }
                ;
            }
            if (i == 16) {
                value = !item ? false : true;
            }
            if ([8, 9, 15, 18].indexOf(i) > -1) {
                if (!item)
                    value = 0;
                else
                    value = new Date(value).valueOf();
            }
            if ([10, 13, 14].indexOf(i) > -1 && !item) {
                value = "";
            }
            if (i == 9 && value != 0)
                addDataInfo.isCreate = false;
            if (i == 10 && value != "")
                addDataInfo.isCreate = false;
            addDataInfo[key] = value;
        }
        if (!isJump)
            addList.push(addDataInfo);
    });
    await enterprise_1.createEnterpriseToList(addList);
    console.log("---> 企业数据 初始化成功");
}
//# sourceMappingURL=dataInit.js.map