"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.changeEnumValue = exports.checkEnumValue = exports.extractData = exports.getToken = exports.checkParamaterType = exports.checkReqParam = exports.getPwdMd5 = exports.checkChange = exports.checkParamater = exports.getTimeKey = exports.getTaskId = void 0;
const moment = require("moment");
const errorEnum_1 = require("../config/errorEnum");
const bizError_1 = require("./bizError");
const md5 = require("md5");
/**
 * 生成任务id
 * @param uscc 企业标识
 * @returns
 */
function getTaskId(uscc) {
    return `${uscc}${getTimeKey()}`;
}
exports.getTaskId = getTaskId;
/**
 * 获取当前日期的key
 * @returns
 */
function getTimeKey() {
    return `${new Date().getFullYear()}${new Date().getMonth() + 1}`;
}
exports.getTimeKey = getTimeKey;
/**
 * 通过config校验参数param
 * 包括类型 String, Number, Boolean, [Number]
 * @param name 被调用的方法名
 * @param config 校验配置
 * @param param 需要校验的参数
 */
function checkParamater(name, keyTypeConf, param, skipKeys) {
    for (let key in keyTypeConf) {
        if (skipKeys && skipKeys.indexOf(key) > -1 && !param[key]) {
            continue;
        }
        if (typeof param[key] != 'boolean' && !param[key])
            throw new bizError_1.BizError(errorEnum_1.ERRORENUM.表单校验失败, name, `缺失${key}字段`);
        let type = typeof param[key];
        switch (keyTypeConf[key]) {
            case 'Number':
                if (type != 'number')
                    throw new bizError_1.BizError(errorEnum_1.ERRORENUM.表单校验失败, name, `${key}应是number型 而不是${type}`);
                break;
            case 'String':
                if (type != 'string')
                    throw new bizError_1.BizError(errorEnum_1.ERRORENUM.表单校验失败, name, `${key}应是string型 而不是${type}`);
                break;
            case 'Boolean':
                if (type != 'boolean')
                    throw new bizError_1.BizError(errorEnum_1.ERRORENUM.表单校验失败, name, `${key}应是boolean型 而不是${type}`);
                break;
            case '[Number]':
                if (!Array.isArray(param[key]))
                    throw new bizError_1.BizError(errorEnum_1.ERRORENUM.表单校验失败, name, `${key}应是数组型 而不是${type}`);
                for (let i = 0; i < param[key].length; i++) {
                    let item = param[key][i];
                    if (typeof item != 'number') {
                        throw new bizError_1.BizError(errorEnum_1.ERRORENUM.表单校验失败, name, `${key}应是number型数组其中下标${i}是${typeof item}`);
                    }
                }
                break;
            case '[Object]':
                if (!Array.isArray(param[key]))
                    throw new bizError_1.BizError(errorEnum_1.ERRORENUM.表单校验失败, name, `${key}应是数组型 而不是${type}`);
                for (let i = 0; i < param[key].length; i++) {
                    let item = param[key][i];
                    if (typeof item != 'object') {
                        throw new bizError_1.BizError(errorEnum_1.ERRORENUM.表单校验失败, name, `${key}应是object型数组其中下标${i}是${typeof item}`);
                    }
                }
                break;
        }
    }
    for (let key in param) {
        if (!keyTypeConf[key])
            throw new bizError_1.BizError(errorEnum_1.ERRORENUM.表单校验失败, name, `多余${key}字段`);
    }
    return true;
}
exports.checkParamater = checkParamater;
/**
 * 匹配新旧对象变化
 * 将newObj 与 oldObj 比对，将newObj中发生变化的key返回
 * 使用前需要校验对象中的内容
 * @param newObj 新对象
 * @param oldObj 旧对象
 * @returns [key] 发生变化的key
 */
function checkChange(newObj, oldObj) {
    let changeKeyList = [];
    for (let newKey in newObj) {
        if (`${newObj[newKey]}` != `${oldObj[newKey]}`)
            changeKeyList.push(newKey);
    }
    return changeKeyList;
}
exports.checkChange = checkChange;
/**
 * 密码加密
 * @param uscc 信用代码
 * @param pwd 密码
 * @returns md5后的密码
 */
function getPwdMd5(uscc, pwd) {
    return md5(uscc + pwd);
}
exports.getPwdMd5 = getPwdMd5;
/**
 * 校验请求参数
 * 判断参数为必填
 * @param conf
 * @param param
 * @returns
 */
function checkReqParam(conf, param) {
    for (let key in conf) {
        if (typeof param[key] != 'boolean' && !param[key])
            throw new bizError_1.BizError(errorEnum_1.ERRORENUM.参数错误, `缺失${key}字段`);
        let type = typeof param[key];
        switch (conf[key]) {
            case 'Number':
                if (type != 'number')
                    throw new bizError_1.BizError(errorEnum_1.ERRORENUM.参数错误, `${key}应是number型 而不是${type}`);
                break;
            case 'String':
                if (type != 'string')
                    throw new bizError_1.BizError(errorEnum_1.ERRORENUM.参数错误, `${key}应是string型 而不是${type}`);
                break;
            case 'Boolean':
                if (type != 'boolean')
                    throw new bizError_1.BizError(errorEnum_1.ERRORENUM.参数错误, `${key}应是boolean型 而不是${type}`);
                break;
            case '[Number]':
                if (!Array.isArray(param[key]))
                    throw new bizError_1.BizError(errorEnum_1.ERRORENUM.参数错误, `${key}应是数组型 而不是${type}`);
                for (let i = 0; i < param[key].length; i++) {
                    let item = param[key][i];
                    if (typeof item != 'number') {
                        throw new bizError_1.BizError(errorEnum_1.ERRORENUM.参数错误, `${key}应是number型数组其中下标${i}是${typeof item}`);
                    }
                }
                break;
            case 'Object':
                if (type != 'object')
                    throw new bizError_1.BizError(errorEnum_1.ERRORENUM.参数错误, `${key}应是Object型 而不是${type}`);
                if (Array.isArray(param[key]))
                    throw new bizError_1.BizError(errorEnum_1.ERRORENUM.参数错误, `${key}应是Object型 而不是array`);
                try {
                    JSON.stringify(param[key]);
                }
                catch (err) {
                    throw new bizError_1.BizError(errorEnum_1.ERRORENUM.参数错误, `${key}应是Object型 转换JSON时失败`);
                }
                break;
        }
    }
    for (let key in param) {
        if (!conf[key])
            throw new bizError_1.BizError(errorEnum_1.ERRORENUM.表单校验失败, `多余${key}字段`);
    }
    return param;
}
exports.checkReqParam = checkReqParam;
/**
 * 校验请求参数
 * 判断参数可以不填
 * @param conf
 * @param param
 * @returns
 */
function checkParamaterType(conf, param) {
    for (let key in conf) {
        if (!param[key])
            continue;
        let type = typeof param[key];
        switch (conf[key]) {
            case 'Number':
                if (type != 'number')
                    throw new bizError_1.BizError(errorEnum_1.ERRORENUM.参数错误, `${key}应是number型 而不是${type}`);
                break;
            case 'String':
                if (type != 'string')
                    throw new bizError_1.BizError(errorEnum_1.ERRORENUM.参数错误, `${key}应是string型 而不是${type}`);
                break;
            case 'Boolean':
                if (type != 'boolean')
                    throw new bizError_1.BizError(errorEnum_1.ERRORENUM.参数错误, `${key}应是boolean型 而不是${type}`);
                break;
            case '[Number]':
                if (!Array.isArray(param[key]))
                    throw new bizError_1.BizError(errorEnum_1.ERRORENUM.参数错误, `${key}应是数组型 而不是${type}`);
                for (let i = 0; i < param[key].length; i++) {
                    let item = param[key][i];
                    if (typeof item != 'number') {
                        throw new bizError_1.BizError(errorEnum_1.ERRORENUM.参数错误, `${key}应是number型数组其中下标${i}是${typeof item}`);
                    }
                }
                break;
            case 'Object':
                if (type != 'object')
                    throw new bizError_1.BizError(errorEnum_1.ERRORENUM.参数错误, `${key}应是Object型 而不是${type}`);
                if (Array.isArray(param[key]))
                    throw new bizError_1.BizError(errorEnum_1.ERRORENUM.参数错误, `${key}应是Object型 而不是array`);
                try {
                    JSON.stringify(param[key]);
                }
                catch (err) {
                    throw new bizError_1.BizError(errorEnum_1.ERRORENUM.参数错误, `${key}应是Object型 转换JSON时失败`);
                }
                break;
        }
    }
    for (let key in param) {
        if (!conf[key])
            throw new bizError_1.BizError(errorEnum_1.ERRORENUM.表单校验失败, `多余${key}字段`);
    }
    return param;
}
exports.checkParamaterType = checkParamaterType;
/**
 * 获取token
 * @param uscc 统一信用代码
 */
function getToken(uscc) {
    return md5(`${uscc}${new Date().valueOf()}${Math.ceil(Math.random() * 100)}`);
}
exports.getToken = getToken;
/**
 * 根据conf截取data中的数据
 * @param conf
 * @param data
 * @returns
 */
function extractData(conf, data, isAdmin) {
    let result = {};
    for (let key in conf) {
        let confInfo = conf[key];
        if (confInfo.changeDate) {
            if (isAdmin)
                result[key] = moment(data[key]).format("YYYY-MM-DD");
            else
                result[key] = data[key] || 0;
        }
        else {
            result[key] = data[key];
            if (typeof result[key] == 'string' && !result[key])
                result[key] = '';
        }
    }
    return result;
}
exports.extractData = extractData;
/**
 * 校验value是否符合传入的枚举
 * @param enumConf 目标枚举
 * @param value 目标值
 * @returns true/false 是否通过校验
 */
function checkEnumValue(enumConf, value) {
    if (typeof value == 'number') {
        return enumConf[value] ? true : false;
    }
    let checkSuccess = true;
    value.forEach(item => {
        if (!enumConf[item])
            checkSuccess = false;
    });
    return checkSuccess;
}
exports.checkEnumValue = checkEnumValue;
/**
 * 将枚举值转换成对应的枚举名(key)
 * @param enumConf 目标枚举
 * @param value 目标值
 * @returns string  返回字符串 如果传入多个枚举值，就拼接字符串
 */
function changeEnumValue(enumConf, value) {
    if (!value)
        return '';
    if (typeof value == 'number') {
        return enumConf[value];
    }
    let str = "";
    value.forEach((item, index) => {
        str += enumConf[item];
        if (index == value.length - 1)
            str += "";
        else
            str += ",";
    });
    return str;
}
exports.changeEnumValue = changeEnumValue;
//# sourceMappingURL=tools.js.map