/**
 * 小程序端  孵化器入口  孵化器相关路由
 * 包括 孵化器数据相关
 * 包括 孵化器任务相关
 */

import * as asyncHandler from 'express-async-handler';
import * as baseBiz from '../../biz/fuHuqQi/base';
import * as taskBiz from '../../biz/fuHuqQi/task';
import { eccReqMustHaveParam } from '../../util/verificationParam';
import { checkFuHuaQiToken } from '../../middleware/user';

export function setRouter(httpServer) {
    httpServer.post('/fuhuaqi/base', checkFuHuaQiToken, asyncHandler(baseInfo));
    httpServer.post('/fuhuaqi/mydata', checkFuHuaQiToken, asyncHandler(myDataInfo));
    httpServer.post('/fuhuaqi/base/update', checkFuHuaQiToken, asyncHandler(updateMyDataInfo));
    httpServer.post('/fuhuaqi/organization/info', checkFuHuaQiToken, asyncHandler(organizationInfo));
    httpServer.post('/fuhuaqi/organization/update', checkFuHuaQiToken, asyncHandler(updateOrganizationInfo));
    /** 任务 */
    httpServer.post('/fuhuaqi/task/list', checkFuHuaQiToken, asyncHandler(taskList));
    httpServer.post('/fuhuaqi/task/submit', checkFuHuaQiToken, asyncHandler(submitTask));
}


/**
 * 主界面信息 
 * 包括首页的 我的数据 评分明细
 * @param req 
 * @param res 
 */
async function baseInfo(req, res) {
    const Uscc = req.headers.uscc;
    let userInfo = await baseBiz.homeData(Uscc);
    res.success(userInfo);
}


/**
 * 我的数据 
 * 小程序点击 详细数据
 * @param req 
 * @param res 
 */
async function myDataInfo(req, res) {
    const Uscc = req.headers.uscc;
    let userInfo = await baseBiz.selectFuHuaQiBaseData(Uscc);
    res.success(userInfo);
}


/**
 * 更新基础数据
 * @param req 
 * @param res 
 */
async function updateMyDataInfo(req, res) {
    let reqConf = {form: 'Object' };
    let { form } = eccReqMustHaveParam(reqConf, req.body);
    const Uscc = req.headers.uscc;

    let result = await baseBiz.updateFuHuaQiBaseData(Uscc, form);
    res.success(result);
}


/**
 * 机构信息
 */
async function organizationInfo(req, res) {
    const Uscc = req.headers.uscc;
    let userInfo = await baseBiz.selectOrganizationInfo(Uscc);
    res.success(userInfo);
}


/**
 * 修改机构信息
 */
async function updateOrganizationInfo(req, res) {
    let reqConf = {form: 'Object' };
    let { form } = eccReqMustHaveParam(reqConf, req.body);
    const Uscc = req.headers.uscc;

    let result = await baseBiz.updateOrganizationData(Uscc, form);
    res.success(result);
}


/**
 * 任务列表
 * @param req 
 * @param res 
 */
async function taskList(req, res) {
    const Uscc = req.headers.uscc;
    let result = await taskBiz.fuHuaQiTaskList(Uscc);
    res.success(result);
}


/**
 * 提交任务
 * @param req 
 * @param res 
 */
async function submitTask(req, res) {
    let reqConf = {taskType:'Number'};
    let { taskType } = eccReqMustHaveParam(reqConf, req.body);
    const Uscc = req.headers.uscc;

    let result = await taskBiz.checkTask(Uscc, taskType);
    res.success(result);
}